@@ -92,33 +92,33 @@ class SpacyRulesParameters(SegmenterParameters):
                                                     description="""List of split rules that operates over tokens based on the [Spacy Rule-based matcher](https://spacy.io/usage/rule-based-matching) syntax<br/>
                                                     The rules can refer to token annotations (e.g. the token text and flags (e.g. IS_PUNCT), the sentence start always at the last token a of sequennce.<br/>
                                                     Let's suppose you want to force sentence to start on word triggers like Title/Chapter, then you need to define a single rule composed of 2 tokens:<ol>
-                                                    <li>A token whose `IS_SPACE` flag is set to true and that contains at least one line break `\n`
-                                                    <li>A token whose text is in a list of predefined paragraph triggers `["Chapter", "Title"]`
+                                                    <li>A token whose `IS_SPACE` flag is set to true and that contains at least one line break `\\n`
+                                                    <li>A token whose `TEXT` is in a list of predefined paragraph triggers `["Chapter", "Title"]`
                                                     </ol>
                                                     Then you need to define a rule like:<br/>
-                                                    ```[
-                                                        [
-                                                            {
-                                                                "__comment": "Split on line break...",
-                                                                "IS_SPACE": True,
-                                                                "TEXT": {
-                                                                    "REGEX": "(.?\n){1,}"
-                                                                }
-                                                            },
-                                                            {
-                                                                "__comment1": "... only if followed by paragraph trigger word",
-                                                                "LOWER": {
-                                                                    "IN": [
-                                                                        "chapter", "title"
-                                                                    ]
-                                                                },
-                                                                "__comment2": "... starting by an uppercase letter",
-                                                                "SHAPE": {
-                                                                    "REGEX": "^X"
-                                                                }
-                                                            }
-                                                        ]
-                                                    ]```
+                                                    ```[<br/>
+                                                        [<br/>
+                                                            {<br/>
+                                                                "__comment": "Split on line break...",<br/>
+                                                                "IS_SPACE": True,<br/>
+                                                                "TEXT": {<br/>
+                                                                    "REGEX": "(.?\n){1,}"<br/>
+                                                                }<br/>
+                                                            },<br/>
+                                                            {<br/>
+                                                                "__comment1": "... only if followed by paragraph trigger word",<br/>
+                                                                "LOWER": {<br/>
+                                                                    "IN": [<br/>
+                                                                        "chapter", "title"<br/>
+                                                                    ]<br/>
+                                                                },<br/>
+                                                                "__comment2": "... starting by an uppercase letter",<br/>
+                                                                "SHAPE": {<br/>
+                                                                    "REGEX": "^X"<br/>
+                                                                }<br/>
+                                                            }<br/>
+                                                        ]<br/>
+                                                    ]```<br/>
                                                     Keys starting with `__comment` are considered as comments""",
                                                     extra="json")
     join_rules: List[List[Dict[str, Any]]] = Field(JOIN_DEFAULT,
